@@ -2,9 +2,9 @@
 ### ====================================================================
 ###  @UNIX-shell-file{
 ###     author          = "Nelson H. F. Beebe",
-###     version         = "0.06",
-###     date            = "04 December 1994",
-###     time            = "13:00:53 MST",
+###     version         = "0.07",
+###     date            = "17 January 1996",
+###     time            = "05:57:04 MST",
 ###     filename        = "biborder.sh",
 ###     address         = "Center for Scientific Computing
 ###                        Department of Mathematics
@@ -13,7 +13,7 @@
 ###                        USA",
 ###     telephone       = "+1 801 581 5254",
 ###     FAX             = "+1 801 581 4148",
-###     checksum        = "64732 824 2819 23945",
+###     checksum        = "07194 831 2848 24194",
 ###     email           = "beebe@math.utah.edu (Internet)",
 ###     codetable       = "ISO/ASCII",
 ###     keywords        = "bibliography, ordering, BibTeX",
@@ -600,7 +600,8 @@ function collect_braced_item( count,item,k,s)
     # any that do not exist, so that key/value pairs are not duplicated
     # in the collections after sort_keys().  The list here includes all
     # of the field names defined in the GNU Emacs bibtex.el support
-    # code, plus key, ISBN, ISSN, LCCN, price, and URL.
+    # code, plus CODEN, day, key, ISBN, ISSN, LCCN, MRnumber, MRclass,
+    # price, and URL.
 
     item = item get_pair("author")
     item = item get_pair("editor")
@@ -621,11 +622,17 @@ function collect_braced_item( count,item,k,s)
     item = item get_pair("address")
     item = item get_pair("edition")
     item = item get_pair("pages")
+    item = item get_pair("day")
     item = item get_pair("month")
     item = item get_pair("year")
+    item = item get_pair("CODEN")
     item = item get_pair("ISBN")
     item = item get_pair("ISSN")
     item = item get_pair("LCCN")
+    item = item get_pair("MRclass")
+    item = item get_pair("MRnumber")
+    item = item get_pair("bibdate")
+    item = item get_pair("bibsource")
     item = item get_pair("note")
     item = item get_pair("price")
     item = item get_pair("series")
